Tests that use ExpectedException have fallen out of flavor as these lack
granularity, are misleading, and may pass for the wrong reason.

Using try and catch is verbose.

One possibility is to use lamba expressions and gain the granularity. For example,

    class TestHelper
    {
        public static ExceptionType ShouldThrow<ExceptionType>(Action action, String message) where ExceptionType : Exception
        {
            try
            {
                action();
                Assert.Fail(message);
            }
            catch (ExceptionType ex)
            {
                return ex;
            }
            return null;
        }
    }

Then you can do the following:
        [TestMethod]
        public void MonitorInvalidPathConciseTest()
        {
            FileSystemMock fileSystem = new FileSystemMockWithException();
            AlarmMock alarm = new AlarmMock();
            FileMonitor monitor = new FileMonitor(fileSystem, alarm);

            TestHelper.ShouldThrow<FileSystemException>(
                () => monitor.PathToObserve = "INVALID",
                "Expected exception for setting invalid path");
        }
